.. _all-salt.renderers:

================
renderer modules
================

.. include:: ../../../_incl/jinja_security.rst

.. currentmodule:: salt.renderers

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    aws_kms
    cheetah
    dson
    genshi
    gpg
    hjson
    jinja
    json
    json5
    mako
    msgpack
    nacl
    pass
    py
    pydsl
    pyobjects
    stateconf
    tomlmod
    wempy
    yaml
    yamlex
